@@ -22,7 +22,7 @@ def create_graph_table():
     sql = """
         CREATE TABLE IF NOT EXISTS Graphs (
         id INTEGER PRIMARY KEY AUTOINCREMENT,
-        actions TEXT NOT NULL
+        action TEXT NOT NULL
         );
         """
     return sql
